@@ -1454,7 +1454,7 @@ rpcapi_cap_opts = [
         'taskmanager', default='latest',
         help='Set a version cap for messages sent to taskmanager services'),
     cfg.StrOpt(
-        'guestagent', default='latest',
+        'guestagent', default='zed',
         help='Set a version cap for messages sent to guestagent services'),
     cfg.StrOpt(
         'conductor', default='latest',
