@@ -267,7 +267,8 @@ class PgSqlApp(service.BaseDbApp):
 
         os_cred = (f"--os-token={context.auth_token} "
                    f"--os-auth-url={CONF.service_credentials.auth_url} "
-                   f"--os-tenant-id={context.project_id}")
+                   f"--os-tenant-id={context.project_id} "
+                   f"--os-region-name={CONF.service_credentials.region_name}")
 
         command = (
             f'/usr/bin/python3 main.py --nobackup '
@@ -770,12 +771,15 @@ class PostgresConnection(object):
     def _execute_stmt(self, statement, identifiers, data_values, fetch,
                       autocommit=False):
         cmd = self._bind(statement, identifiers)
-        with psycopg2.connect(self.connect_str) as connection:
-            connection.autocommit = autocommit
+        connection = psycopg2.connect(self.connect_str)
+        connection.autocommit = autocommit
+        try:
             with connection.cursor() as cursor:
                 cursor.execute(cmd, data_values)
                 if fetch:
                     return cursor.fetchall()
+        finally:
+            connection.close()
 
     def _bind(self, statement, identifiers):
         if identifiers:
